@@ -48,6 +48,10 @@ see https://www.gnu.org/licenses/. */
 #include <pagmo/s11n.hpp>
 #include <pagmo/types.hpp>
 
+// NOTE: apparently this must be included *after*
+// the other serialization headers.
+#include <boost/serialization/optional.hpp>
+
 namespace pagmo
 {
 
@@ -195,7 +199,7 @@ population cmaes::evolve(population pop) const
     vector_double dumb(dim, 0.);
 
     // If the algorithm is called for the first time on this problem dimension / pop size or if m_memory is false we
-    // erease the memory of past calls
+    // erase the memory of past calls
     if ((newpop.size() != lam) || (static_cast<unsigned>(newpop[0].rows()) != dim) || (m_memory == false)) {
         sigma = m_sigma0;
         mean.resize(_(dim));
@@ -209,7 +213,7 @@ population cmaes::evolve(population pop) const
         // We define the starting B,D,C
         B = Eigen::MatrixXd::Identity(_(dim), _(dim)); // B defines the coordinate system
         D = Eigen::MatrixXd::Identity(_(dim), _(dim));
-        // diagonal D defines the scaling. By default this is the witdh of the box bounds.
+        // diagonal D defines the scaling. By default this is the width of the box bounds.
         // If this is too small... then 1e-6 is used
         for (decltype(dim) j = 0u; j < dim; ++j) {
             D(_(j), _(j)) = std::max((ub[j] - lb[j]), 1e-6);
@@ -273,9 +277,9 @@ population cmaes::evolve(population pop) const
         if (m_verbosity > 0u) {
             // Every m_verbosity generations print a log line
             if (gen % m_verbosity == 1u || m_verbosity == 1u) {
-                // The population flattness in chromosome
+                // The population flatness in chromosome
                 auto dx = (sigma * B * D * tmp).norm();
-                // The population flattness in fitness
+                // The population flatness in fitness
                 auto idx_b = pop.best_idx();
                 auto idx_w = pop.worst_idx();
                 auto df = std::abs(pop.get_f()[idx_b][0] - pop.get_f()[idx_w][0]);
@@ -316,7 +320,30 @@ population cmaes::evolve(population pop) const
             for (decltype(dim) j = 0u; j < dim; ++j) {
                 dumb[j] = newpop[i](_(j));
             }
-            pop.set_x(i, dumb);
+            if (!m_bfe) {
+                // bfe not available
+                pop.set_x(i, dumb);
+            }
+        }
+        if (m_bfe) {
+            // bfe is available:
+            vector_double decision_vectors(lam * dim);
+            vector_double::size_type pos = 0u;
+            for (decltype(lam) i = 0u; i < lam; ++i) {
+                for (decltype(dim) j = 0u; j < dim; ++j) {
+                    decision_vectors[pos] = newpop[i](_(j));
+                    ++pos;
+                }
+            }
+            // run bfe.
+            auto fitnesses = (*m_bfe)(prob, decision_vectors);
+
+            for (decltype(lam) i = 0u; i < lam; ++i) {
+                for (decltype(dim) j = 0u; j < dim; ++j) {
+                    dumb[j] = newpop[i](_(j));
+                }
+                pop.set_xf(i, dumb, {fitnesses[i]});
+            }
         }
         counteval += lam;
         // 4 - We extract the elite from this generation.
@@ -370,7 +397,7 @@ population cmaes::evolve(population pop) const
                     Dinv(_(j), _(j)) = 1. / D(_(j), _(j));
                 }
                 invsqrtC = B * Dinv * B.transpose();
-            } // if eigendecomposition fails just skip it and keep pevious successful one.
+            } // if eigendecomposition fails just skip it and keep previous successful one.
         }
     } // end of generation loop
     if (m_verbosity) {
@@ -389,6 +416,15 @@ void cmaes::set_seed(unsigned seed)
     m_seed = seed;
 }
 
+/// Sets the batch function evaluation scheme
+/**
+ * @param b batch function evaluation object
+ */
+void cmaes::set_bfe(const bfe &b)
+{
+    m_bfe = b;
+}
+
 /// Extra info
 /**
  * One of the optional methods of any user-defined algorithm (UDA).
@@ -434,8 +470,8 @@ template <typename Archive>
 void cmaes::serialize(Archive &ar, unsigned)
 {
     detail::archive(ar, m_gen, m_cc, m_cs, m_c1, m_cmu, m_sigma0, m_ftol, m_xtol, m_memory, m_force_bounds, sigma, mean,
-                    variation, newpop, B, D, C, invsqrtC, pc, ps, counteval, eigeneval, m_e, m_seed, m_verbosity,
-                    m_log);
+                    variation, newpop, B, D, C, invsqrtC, pc, ps, counteval, eigeneval, m_e, m_seed, m_verbosity, m_log,
+                    m_bfe);
 }
 
 } // namespace pagmo
